# Generated by roxygen2: do not edit by hand

export(compare_var_structure)
export(create_calc_config)
export(create_initial_config)
export(create_target_config)
export(export_data)
export(get_data_by_dims)
export(get_data_by_var)
export(get_dim_elements)
export(get_dim_patterns)
export(get_var_structure)
export(group_data_by_dims)
export(load_harx)
export(load_sl4x)
export(pivot_data)
export(pivot_data_hierarchy)
export(rename_dims)
export(save_har)
export(shock_calculate)
export(shock_calculate_uniform)
importFrom(haven,write_dta)
importFrom(openxlsx,addStyle)
importFrom(openxlsx,addWorksheet)
importFrom(openxlsx,createStyle)
importFrom(openxlsx,createWorkbook)
importFrom(openxlsx,saveWorkbook)
importFrom(openxlsx,writeData)
importFrom(stats,complete.cases)
importFrom(stats,setNames)
importFrom(tidyr,pivot_wider)
importFrom(tidyselect,all_of)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,read.csv)
importFrom(utils,tail)
importFrom(utils,write.csv)
importFrom(utils,write.table)
